==> elm-ts-0.5.3.tgz: package/es6/Debug/commons.js <==
/**
 * Common utilities and type definitions for the `Debug` module.
 *
 * @since 0.5.0
 */
import { chain, map } from 'fp-ts/es6/IO';
import { fold } from 'fp-ts/es6/Option';
import { pipe } from 'fp-ts/es6/pipeable';
import { none } from '../Cmd';
import { consoleDebugger } from './console';
import { getConnection, reduxDevToolDebugger } from './redux-devtool';
/**
 * Creates a `DebugInit`
 * @since 0.5.0
 */
export const debugInit = () => ({ type: 'INIT' });
/**
 * Creates a `DebugMsg`
 * @since 0.5.0
 */
export const debugMsg = (payload) => ({ type: 'MESSAGE', payload });
/**
 * Adds debugging capability to the provided `update` function.
 *
 * It tracks through the `debug$` stream every `Message` dispatched and resulting `Model` update.
 *
 * It also lets directly updating the application's state with a special `Message` of type:
 *
 * ```ts
 * {
 *   type: '__DebugUpdateModel__'
 *   payload: Model
 * }
 * ```
 *
 * or applying a message with:
 * ```ts
 * {
 *   type: '__DebugApplyMsg__';
 *   payload: Msg
 * }
 * ```
 * @since 0.5.3
 */
export function updateWithDebug(debug$, update) {
    return (msg, model) => {
        if ('type' in msg) {
            switch (msg.type) {
                case '__DebugUpdateModel__':
                    return [msg.payload, none];
                case '__DebugApplyMsg__':
                    return [update(msg.payload, model)[0], none];
            }
        }
        const result = update(msg, model);
        debug$.next([debugMsg(msg), result[0]]);
        return result;
    };
}
/**
 * Checks which type of debugger can be used (standard `console` or _Redux DevTool Extension_) based on provided `window` and prepares the subscription to the "debug" stream
 * @since 0.5.3
 */
export function runDebugger(win) {
    return deps => pipe(getConnection(win), map(fold(() => consoleDebugger(), reduxDevToolDebugger)), chain(Debugger => () => deps.debug$.subscribe(Debugger(deps))));
}

==> elm-ts-0.5.4.tgz: package/es6/Debug/commons.js <==
/**
 * Common utilities and type definitions for the `Debug` module.
 *
 * @since 0.5.0
 */
import { chain, map } from 'fp-ts/es6/IO';
import { fold } from 'fp-ts/es6/Option';
import { pipe } from 'fp-ts/es6/pipeable';
import { takeUntil } from 'rxjs/operators';
import { none } from '../Cmd';
import { consoleDebugger } from './console';
import { getConnection, reduxDevToolDebugger } from './redux-devtool';
/**
 * Creates a `DebugInit`
 * @since 0.5.0
 */
export const debugInit = () => ({ type: 'INIT' });
/**
 * Creates a `DebugMsg`
 * @since 0.5.0
 */
export const debugMsg = (payload) => ({ type: 'MESSAGE', payload });
/**
 * Adds debugging capability to the provided `update` function.
 *
 * It tracks through the `debug$` stream every `Message` dispatched and resulting `Model` update.
 *
 * It also lets directly updating the application's state with a special `Message` of type:
 *
 * ```ts
 * {
 *   type: '__DebugUpdateModel__'
 *   payload: Model
 * }
 * ```
 *
 * or applying a message with:
 * ```ts
 * {
 *   type: '__DebugApplyMsg__';
 *   payload: Msg
 * }
 * ```
 * @since 0.5.3
 */
export function updateWithDebug(debug$, update) {
    return (msg, model) => {
        if ('type' in msg) {
            switch (msg.type) {
                case '__DebugUpdateModel__':
                    return [msg.payload, none];
                case '__DebugApplyMsg__':
                    return [update(msg.payload, model)[0], none];
            }
        }
        const result = update(msg, model);
        debug$.next([debugMsg(msg), result[0]]);
        return result;
    };
}
/**
 * Checks which type of debugger can be used (standard `console` or _Redux DevTool Extension_) based on provided `window` and prepares the subscription to the "debug" stream
 *
 * **Warning:** this function **SHOULD** be considered as an internal method; using it in your application **SHOULD** be avoided.
 * @since 0.5.4
 */
export function runDebugger(win, stop$) {
    return deps => pipe(getConnection(win), map(fold(() => consoleDebugger(), reduxDevToolDebugger)), chain(Debugger => () => {
        const { debug, stop } = Debugger(deps);
        deps.debug$.pipe(takeUntil(stop$)).subscribe({
            next: debug,
            complete: stop
        });
    }));
}
